@@ -97,14 +97,14 @@ glade_xml_init (GladeXML *self)
 	self->priv = priv = g_new (GladeXMLPrivate, 1);
 
 	self->filename = NULL;
-	self->textdomain = NULL;
+	self->txtdomain = NULL;
 	priv->tooltips = NULL;
 	priv->name_hash = g_hash_table_new(g_str_hash, g_str_equal);
 	priv->longname_hash = g_hash_table_new(g_str_hash, g_str_equal);
 	priv->signals = g_hash_table_new(g_str_hash, g_str_equal);
 	priv->radio_groups = g_hash_table_new (g_str_hash, g_str_equal);
 	priv->toplevel = NULL;
-	priv->accel_group = NULL;
+	priv->accel_groups = NULL;
 	priv->uline_accels = NULL;
 	priv->parent_accel = 0;
 	priv->focus_ulines = NULL;
@@ -195,8 +195,8 @@ glade_xml_construct (GladeXML *self, const char *fname, const char *root,
 		return FALSE;
 
 	self->priv->tree = tree;
-	if (self->textdomain) g_free(self->textdomain);
-	self->textdomain = g_strdup(domain);
+	if (self->txtdomain) g_free(self->txtdomain);
+	self->txtdomain = g_strdup(domain);
 	if (self->filename)
 		g_free(self->filename);
 	self->filename = g_strdup(fname);
@@ -234,7 +234,7 @@ GladeXML *glade_xml_new_from_memory(char *buffer, int size, const char *root,
 	self = gtk_type_new(glade_xml_get_type());
 
 	self->priv->tree = tree;
-	self->textdomain = g_strdup(domain);
+	self->txtdomain = g_strdup(domain);
 	self->filename = NULL;
 	glade_xml_build_interface(self, tree, root);
 
@@ -708,10 +708,45 @@ glade_xml_set_toplevel(GladeXML *xml, GtkWindow *window)
 	xml->priv->default_widget = NULL;
 	xml->priv->toplevel = window;
 	/* new toplevel needs new accel group */
-	xml->priv->accel_group = NULL;
+	g_slist_free(xml->priv->accel_groups);
+	xml->priv->accel_groups = NULL;
 	xml->priv->parent_accel = 0;
 }
 
+ /**
+ * glade_xml_push_accel:
+ * @xml: the GladeXML object.
+ *
+ * Make a new accel group amd push onto the stack.  This is intended for use
+ * by GtkNotebook so that each notebook page can set up its own accelerators.
+ * Returns: The current GtkAccelGroup after push.
+ */
+GtkAccelGroup *
+glade_xml_push_accel(GladeXML *xml) {
+	GtkAccelGroup *accel = gtk_accel_group_new();
+       
+	xml->priv->accel_groups
+		= g_slist_prepend(xml->priv->accel_groups, accel);
+	return accel;
+}
+
+/* glade_xml_pop_accel:
+ * @xml: the GladeXML object.
+ *
+ * Pops the accel group.  This will usually be called after a GtkNotebook page
+ * has been built.
+ * Returns: The current GtkAccelGroup after pop.
+ */
+GtkAccelGroup *
+glade_xml_pop_accel(GladeXML *xml) {
+	g_return_val_if_fail(xml->priv->accel_groups != NULL, NULL);
+
+	xml->priv->accel_groups
+		= g_slist_remove(xml->priv->accel_groups,
+				 xml->priv->accel_groups->data);
+	return xml->priv->accel_groups ? xml->priv->accel_groups->data : NULL;
+}
+
 /**
  * glade_xml_ensure_accel:
  * @xml: the GladeXML object.
@@ -724,13 +759,13 @@ glade_xml_set_toplevel(GladeXML *xml, GtkWindow *window)
 GtkAccelGroup *
 glade_xml_ensure_accel(GladeXML *xml)
 {
-	if (!xml->priv->accel_group) {
-		xml->priv->accel_group = gtk_accel_group_new();
+	if (!xml->priv->accel_groups) {
+		glade_xml_push_accel(xml);
 		if (xml->priv->toplevel)
 			gtk_window_add_accel_group(xml->priv->toplevel,
-						   xml->priv->accel_group);
+					xml->priv->accel_groups->data);
 	}
-	return xml->priv->accel_group;
+	return (GtkAccelGroup *)xml->priv->accel_groups->data;
 }
 
 /**
@@ -850,8 +885,8 @@ glade_xml_gettext(GladeXML *xml, const char *msgid)
 	if (!msgid || msgid[0] == '\0')
 		return "";
 #ifdef ENABLE_NLS
-	if (xml->textdomain)
-		return dgettext(xml->textdomain, msgid);
+	if (xml->txtdomain)
+		return dgettext(xml->txtdomain, msgid);
 	else
 		return gettext(msgid);
 #else
@@ -922,6 +957,12 @@ glade_xml_destroy_signals(char *key, GList *signal_datas)
 	g_list_free(signal_datas);
 }
 
+static void
+free_radio_groups(gpointer key, gpointer value, gpointer user_data)
+{
+	g_free(key);  /* the string name */
+}
+
 static void
 glade_xml_destroy(GtkObject *object)
 {
@@ -930,8 +971,8 @@ glade_xml_destroy(GtkObject *object)
 	
 	if (self->filename)
 		g_free(self->filename);
-	if (self->textdomain)
-		g_free(self->textdomain);
+	if (self->txtdomain)
+		g_free(self->txtdomain);
 
 	if (priv->tree)
 		glade_widget_tree_unref(priv->tree);
@@ -945,7 +986,8 @@ glade_xml_destroy(GtkObject *object)
 	g_hash_table_destroy(priv->signals);
 
 	/* the group name strings are owned by the GladeWidgetTree */
-	g_hash_table_destroy (priv->radio_groups);
+	g_hash_table_foreach(self->priv->radio_groups, free_radio_groups,NULL);
+	g_hash_table_destroy(priv->radio_groups);
 	
 	g_free (self->priv);
 	if (parent_class->destroy)
@@ -1121,11 +1163,10 @@ glade_xml_build_widget(GladeXML *self, GladeWidgetInfo *info,
 			ret = gtk_label_new(buf);
 			gtk_widget_show(ret);
 		}
-		
-		return ret;
+	} else {
+		g_assert(data->new);
+		ret = data->new(self, info);
 	}
-	g_assert(data->new);
-	ret = data->new(self, info);
 	glade_xml_set_common_params(self, ret, info, parent_long);
 	return ret;
 }
@@ -1252,7 +1293,7 @@ glade_xml_set_common_params(GladeXML *self, GtkWidget *widget,
 	if (info->style)
 		glade_style_attach(widget, info->style->name);
 
-	if (data->build_children && info->children)
+	if (data && data->build_children && info->children)
 		data->build_children(self, widget, info, w_longname);
 	if (info->visible)
 		gtk_widget_show(widget);
